summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/command.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/command.h')
-rw-r--r--kdevdesigner/designer/command.h77
1 files changed, 39 insertions, 38 deletions
diff --git a/kdevdesigner/designer/command.h b/kdevdesigner/designer/command.h
index 0279dc50..a44f2431 100644
--- a/kdevdesigner/designer/command.h
+++ b/kdevdesigner/designer/command.h
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000-2002 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -50,7 +50,7 @@ class TQListBox;
class TQIconView;
class TQTable;
class TQAction;
-class QDesignerToolBar;
+class TQDesignerToolBar;
class TQMainWindow;
class TQTextEdit;
struct LanguageInterface;
@@ -62,7 +62,7 @@ class PopupMenuEditor;
class PopupMenuEditorItem;
class ActionEditor;
-class Command : public Qt
+class Command : public TQt
{
public:
Command( const TQString &n, FormWindow *fw );
@@ -147,9 +147,10 @@ private:
};
-class CommandHistory : public QObject
+class CommandHistory : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
CommandHistory( int s );
@@ -207,7 +208,7 @@ public:
private:
TQWidget *widget;
- TQRect geometry;
+ TQRect tqgeometry;
};
@@ -281,7 +282,7 @@ class LayoutHorizontalCommand : public Command
{
public:
LayoutHorizontalCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -289,7 +290,7 @@ public:
Type type() const { return LayoutHorizontal; }
private:
- HorizontalLayout layout;
+ HorizontalLayout tqlayout;
};
@@ -297,7 +298,7 @@ class LayoutHorizontalSplitCommand : public Command
{
public:
LayoutHorizontalSplitCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -305,7 +306,7 @@ public:
Type type() const { return LayoutHorizontalSplitter; }
private:
- HorizontalLayout layout;
+ HorizontalLayout tqlayout;
};
@@ -313,7 +314,7 @@ class LayoutVerticalCommand : public Command
{
public:
LayoutVerticalCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -321,7 +322,7 @@ public:
Type type() const { return LayoutVertical; }
private:
- VerticalLayout layout;
+ VerticalLayout tqlayout;
};
@@ -329,7 +330,7 @@ class LayoutVerticalSplitCommand : public Command
{
public:
LayoutVerticalSplitCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -337,7 +338,7 @@ public:
Type type() const { return LayoutVerticalSplitter; }
private:
- VerticalLayout layout;
+ VerticalLayout tqlayout;
};
@@ -345,7 +346,7 @@ class LayoutGridCommand : public Command
{
public:
LayoutGridCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl, int xres, int yres );
void execute();
@@ -353,7 +354,7 @@ public:
Type type() const { return LayoutGrid; }
private:
- GridLayout layout;
+ GridLayout tqlayout;
};
@@ -361,14 +362,14 @@ class BreakLayoutCommand : public Command
{
public:
BreakLayoutCommand( const TQString &n, FormWindow *fw,
- TQWidget *layoutBase, const TQWidgetList &wl );
+ TQWidget *tqlayoutBase, const TQWidgetList &wl );
void execute();
void unexecute();
Type type() const { return BreakLayout; }
private:
- Layout *layout;
+ Layout *tqlayout;
int spacing;
int margin;
TQWidget *lb;
@@ -444,19 +445,19 @@ private:
TQString tabLabel;
};
-class QDesignerWidgetStack;
+class TQDesignerWidgetStack;
class AddWidgetStackPageCommand : public Command
{
public:
AddWidgetStackPageCommand( const TQString &n, FormWindow *fw,
- QDesignerWidgetStack *ws );
+ TQDesignerWidgetStack *ws );
void execute();
void unexecute();
Type type() const { return AddWidgetStackPage; }
private:
- QDesignerWidgetStack *widgetStack;
+ TQDesignerWidgetStack *widgetStack;
int index;
TQWidget *stackPage;
};
@@ -465,14 +466,14 @@ class DeleteWidgetStackPageCommand : public Command
{
public:
DeleteWidgetStackPageCommand( const TQString &n, FormWindow *fw,
- QDesignerWidgetStack *ws, TQWidget *page );
+ TQDesignerWidgetStack *ws, TQWidget *page );
void execute();
void unexecute();
Type type() const { return DeleteWidgetStackPage; }
private:
- QDesignerWidgetStack *widgetStack;
+ TQDesignerWidgetStack *widgetStack;
int index;
TQWidget *stackPage;
};
@@ -774,7 +775,7 @@ public:
{
TQString text;
TQPixmap pix;
- Q_DUMMY_COMPARISON_OPERATOR( Item )
+ TQ_DUMMY_COMPARISON_OPERATOR( Item )
};
PopulateListBoxCommand( const TQString &n, FormWindow *fw,
@@ -798,7 +799,7 @@ public:
{
TQString text;
TQPixmap pix;
- Q_DUMMY_COMPARISON_OPERATOR( Item )
+ TQ_DUMMY_COMPARISON_OPERATOR( Item )
};
PopulateIconViewCommand( const TQString &n, FormWindow *fw,
@@ -856,7 +857,7 @@ public:
{
TQString text;
TQPixmap pix;
- Q_DUMMY_COMPARISON_OPERATOR( Row )
+ TQ_DUMMY_COMPARISON_OPERATOR( Row )
};
struct Column
@@ -864,7 +865,7 @@ public:
TQString text;
TQPixmap pix;
TQString field;
- Q_DUMMY_COMPARISON_OPERATOR( Column )
+ TQ_DUMMY_COMPARISON_OPERATOR( Column )
};
PopulateTableCommand( const TQString &n, FormWindow *fw, TQTable *t,
@@ -886,7 +887,7 @@ class AddActionToToolBarCommand : public Command
{
public:
AddActionToToolBarCommand( const TQString &n, FormWindow *fw,
- TQAction *a, QDesignerToolBar *tb, int idx );
+ TQAction *a, TQDesignerToolBar *tb, int idx );
void execute();
void unexecute();
@@ -894,7 +895,7 @@ public:
private:
TQAction *action;
- QDesignerToolBar *toolBar;
+ TQDesignerToolBar *toolBar;
int index;
};
@@ -903,7 +904,7 @@ class RemoveActionFromToolBarCommand : public AddActionToToolBarCommand
{
public:
RemoveActionFromToolBarCommand( const TQString &n, FormWindow *fw,
- TQAction *a, QDesignerToolBar *tb, int idx )
+ TQAction *a, TQDesignerToolBar *tb, int idx )
: AddActionToToolBarCommand( n, fw, a, tb, idx ) {}
void execute() { AddActionToToolBarCommand::unexecute(); }
@@ -924,7 +925,7 @@ public:
Type type() const { return AddToolBar; }
protected:
- QDesignerToolBar *toolBar;
+ TQDesignerToolBar *toolBar;
TQMainWindow *mainWindow;
};
@@ -932,7 +933,7 @@ protected:
class RemoveToolBarCommand : public AddToolBarCommand
{
public:
- RemoveToolBarCommand( const TQString &n, FormWindow *fw, TQMainWindow *mw, QDesignerToolBar *tb )
+ RemoveToolBarCommand( const TQString &n, FormWindow *fw, TQMainWindow *mw, TQDesignerToolBar *tb )
: AddToolBarCommand( n, fw, mw ) { toolBar = tb; }
void execute() { AddToolBarCommand::unexecute(); }
@@ -941,7 +942,7 @@ public:
};
-struct QWidgetContainerInterfacePrivate;
+struct TQWidgetContainerInterfacePrivate;
class AddContainerPageCommand : public Command
{
@@ -961,7 +962,7 @@ private:
int index;
TQString pageLabel;
TQWidget *page;
- QWidgetContainerInterfacePrivate *wiface;
+ TQWidgetContainerInterfacePrivate *wiface;
};
@@ -982,7 +983,7 @@ private:
int index;
TQString pageLabel;
TQWidget *page;
- QWidgetContainerInterfacePrivate *wiface;
+ TQWidgetContainerInterfacePrivate *wiface;
};
@@ -1003,7 +1004,7 @@ private:
TQWidget *container;
int index;
TQString oldLabel, newLabel;
- QWidgetContainerInterfacePrivate *wiface;
+ TQWidgetContainerInterfacePrivate *wiface;
};
@@ -1,15 +1,15 @@
** Copyright (C) 2000-2002 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the